import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
  .domain(['apple', 'lemon'])
  .range(['#c11d1d', '#eae600']);

const radiusScale = scaleOrdinal()
  .domain(['apple', 'lemon'])
  .range([80, 50]);

const xPosition = (d, i) => i * 180 + 200;

export const fruitBowl = (selection, props) => {
  const { 
    fruits,
    height,
    onClick,
    selectedFruit
  } = props;
  
  const bowl = selection.selectAll('rect')
    .data([null])
    .enter().append('rect')
      .attr('y', 110)
      .attr('width', 920)
      .attr('height', 300)
      .attr('rx', 300 / 2);
  
  const groups = selection.selectAll('g')
    .data(fruits, d => d.id);
  const groupsEnter = groups.enter().append('g');
  
 
  groupsEnter
    .merge(groups) 
      .attr('transform', (d, i) =>
        `translate(${i * 180 + 100},${height / 2})`);


  groupsEnter.append('circle')
    .merge(groups.select('circle'))
      .attr('fill', d => colorScale(d.type))
      .attr('stroke-width', 1)
    .transition().duration(1000)
      .attr('cx', xPosition/2)
      .attr('r', d => radiusScale(d.type));
   

  groups.exit().selectAll('circle')
    .transition().duration(1000)
  	  .attr('r', 0) 
    .remove(); 
  
  groups
    .merge(groups.select('circle'))
      .attr('stroke-width', 5)
      .attr('stroke', d => 
            d.id === selectedFruit
            ? 'black' 
            : 'none'
           )
      .on('click', d => onClick(d.id))
   
  groupsEnter.append('text')
    .merge(groups.select('text'))
      .text(d => d.type)
      .attr('y', 220)
    .transition().duration(1000)
      .attr('y', 120)

  
  groups.exit('text')
    .transition()
  	  .attr('y', height) 
      .attr('x', xPosition)
    .remove();
}